@@ -1,4 +1,4 @@
-/* $Id: textwidget.cc 610 2006-05-10 14:49:35Z murrayc $ */
+/* $Id: textwidget.cc 970 2008-02-23 18:41:08Z murrayc $ */
 
 /* textwidget.cc
  *
@@ -19,8 +19,13 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <cstring>
 #include "textwidget.h"
 #include "pangomm/fontdescription.h"
+  
+using std::strstr;
+using std::strncmp;
+using std::strlen;
 
 
 TextWidget::TextWidget(bool is_source)
