@@ -1,5 +1,5 @@
 // -*- c++ -*-
-/* $Id: stock.cc 848 2007-06-09 20:03:39Z murrayc $ */
+/* $Id: stock.cc 1001 2008-07-10 20:21:11Z murrayc $ */
 
 /* Copyright (C) 2002 The gtkmm Development Team
  *
@@ -103,8 +103,12 @@ const Gtk::BuiltinStockID OK = { GTK_STOCK_OK };
 const Gtk::BuiltinStockID OPEN = { GTK_STOCK_OPEN };
 const Gtk::BuiltinStockID PASTE = { GTK_STOCK_PASTE };
 const Gtk::BuiltinStockID PREFERENCES = { GTK_STOCK_PREFERENCES };
+const Gtk::BuiltinStockID PAGE_SETUP = { GTK_STOCK_PAGE_SETUP };
 const Gtk::BuiltinStockID PRINT = { GTK_STOCK_PRINT };
+const Gtk::BuiltinStockID PRINT_ERROR = { GTK_STOCK_PRINT_ERROR };
 const Gtk::BuiltinStockID PRINT_PREVIEW = { GTK_STOCK_PRINT_PREVIEW };
+const Gtk::BuiltinStockID PRINT_REPORT = { GTK_STOCK_PRINT_REPORT };
+const Gtk::BuiltinStockID PRINT_WARNING = { GTK_STOCK_PRINT_WARNING };
 const Gtk::BuiltinStockID PROPERTIES = { GTK_STOCK_PROPERTIES };
 const Gtk::BuiltinStockID QUIT = { GTK_STOCK_QUIT };
 const Gtk::BuiltinStockID REDO = { GTK_STOCK_REDO };
