@@ -1,4 +1,4 @@
-/* $Id: generate_defs_gtk.cc,v 1.21 2006/05/09 16:51:35 murrayc Exp $ */
+/* $Id: generate_defs_gtk.cc 934 2007-11-05 16:13:35Z murrayc $ */
 
 /* generate_defs_gtk.cc
  *
@@ -23,6 +23,14 @@
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
 
+#if !defined(G_OS_WIN32)
+#include <gtk/gtkprinter.h>
+#include <gtk/gtkprintjob.h>
+#include <gtk/gtkpagesetupunixdialog.h>
+#include <gtk/gtkprintunixdialog.h>
+#endif /* G_OS_WIN32 */
+
+
 int main (int argc, char *argv[])
 {
   gtk_init(&argc, &argv);
@@ -76,6 +84,7 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_ASSISTANT )
             << get_defs( GTK_TYPE_BIN )
             << get_defs( GTK_TYPE_BOX )
+            << get_defs( GTK_TYPE_BUILDER )
             << get_defs( GTK_TYPE_BUTTON )
             << get_defs( GTK_TYPE_BUTTON_BOX )
             << get_defs( GTK_TYPE_CALENDAR )
@@ -145,7 +154,16 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_PLUG )
 #endif /* G_OS_WIN32 */
             << get_defs( GTK_TYPE_PREVIEW )
+#if !defined(G_OS_WIN32)
+	    << get_defs( GTK_TYPE_PRINTER )
+	    << get_defs( GTK_TYPE_PRINT_JOB )
+#endif /* G_OS_WIN32 */
 	    << get_defs( GTK_TYPE_PRINT_OPERATION )
+	    << get_defs( GTK_TYPE_PRINT_OPERATION_PREVIEW )
+#if !defined(G_OS_WIN32)
+	    << get_defs( GTK_TYPE_PAGE_SETUP_UNIX_DIALOG )
+	    << get_defs( GTK_TYPE_PRINT_UNIX_DIALOG )
+#endif /* G_OS_WIN32 */
             << get_defs( GTK_TYPE_PROGRESS )
             << get_defs( GTK_TYPE_PROGRESS_BAR )
             << get_defs( GTK_TYPE_RADIO_BUTTON )
@@ -153,6 +171,7 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_RADIO_ACTION )            
             << get_defs( GTK_TYPE_RADIO_MENU_ITEM )
             << get_defs( GTK_TYPE_RANGE )
+            << get_defs( GTK_TYPE_RECENT_ACTION )
             << get_defs( GTK_TYPE_RECENT_CHOOSER )
             << get_defs( GTK_TYPE_RECENT_CHOOSER_MENU )
             << get_defs( GTK_TYPE_RECENT_CHOOSER_WIDGET )
@@ -160,6 +179,7 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_RECENT_MANAGER )
             << get_defs( GTK_TYPE_RULER )
             << get_defs( GTK_TYPE_SCALE )
+            << get_defs( GTK_TYPE_SCALE_BUTTON )
             << get_defs( GTK_TYPE_SCROLLBAR )
             << get_defs( GTK_TYPE_SCROLLED_WINDOW )
             << get_defs( GTK_TYPE_SEPARATOR )
@@ -187,6 +207,7 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_TEXT_VIEW )
             << get_defs( GTK_TYPE_TOGGLE_ACTION )            
             << get_defs( GTK_TYPE_TOGGLE_TOOL_BUTTON )  
+            << get_defs( GTK_TYPE_TOOLTIP )
             << get_defs( GTK_TYPE_TOOLTIPS )
             << get_defs( GTK_TYPE_TREE_SELECTION )
             << get_defs( GTK_TYPE_TREE_MODEL_FILTER )            
@@ -195,6 +216,7 @@ int main (int argc, char *argv[])
             << get_defs( GTK_TYPE_TREE_VIEW_COLUMN )
             << get_defs( GTK_TYPE_UI_MANAGER )
             << get_defs( GTK_TYPE_VIEWPORT )
+            << get_defs( GTK_TYPE_VOLUME_BUTTON )
             << get_defs( GTK_TYPE_WIDGET )
             << get_defs( GTK_TYPE_WINDOW );
 
